==> dotclear-2.5.zip: dotclear/plugins/importExport/locales/fr/main.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['Import/Export'] = 'Import/Export';
$GLOBALS['__l10n']['Flat file export'] = 'Exporter un fichier texte';
$GLOBALS['__l10n']['Exports a blog or a full Dotclear installation to flat file.'] = 'Exporte un blog ou toutes les données de Dotclear dans un fichier texte.';
$GLOBALS['__l10n']['Export file not found.'] = 'Fichier d\'export non trouvé.';
$GLOBALS['__l10n']['Failed to compress export file.'] = 'Impossible de compresser le fichier d\'export.';
$GLOBALS['__l10n']['Single blog'] = 'Un seul blog';
$GLOBALS['__l10n']['This will create an export of your current blog: %s'] = 'Ceci va exporter le contenu du blog en cours : %s.';
$GLOBALS['__l10n']['File name:'] = 'Nom du fichier :';
$GLOBALS['__l10n']['Compress file'] = 'Compresser le fichier';
$GLOBALS['__l10n']['You may also want to download your media directory as a zip file'] = 'Vous pouvez également télécharger votre répertoire de médias au format zip.';
$GLOBALS['__l10n']['Export'] = 'Exporter';
$GLOBALS['__l10n']['Multiple blogs'] = 'Tous les blogs';
$GLOBALS['__l10n']['This will create an export of all the content of your database.'] = 'Ceci va exporter le contenu complet de votre base de données.';
$GLOBALS['__l10n']['Congratulation!'] = 'Félicitations !';
$GLOBALS['__l10n']['Your blog has been successfully imported. Welcome on Dotclear 2!'] = 'Votre blog a été importé avec succès. Bienvenue sur Dotclear 2 !';
$GLOBALS['__l10n']['Why don\'t you blog this now?'] = 'Pourquoi ne pas le bloguer maintenant ?';
$GLOBALS['__l10n']['or'] = 'ou';
$GLOBALS['__l10n']['visit your dashboard'] = 'vous rendre sur votre tableau de bord';
$GLOBALS['__l10n']['Dotclear 1.2 import'] = 'Importer depuis Dotclear 1.2';
$GLOBALS['__l10n']['Import a Dotclear 1.2 installation into your current blog.'] = 'Importe un blog Dotclear 1.2 dans votre blog en cours.';
$GLOBALS['__l10n']['This will import your Dotclear 1.2 content as new content in the current blog: %s.'] = 'Ceci va importer votre blog Dotclear 1.2 comme un nouveau contenu dans le blog en cours : %s.';
$GLOBALS['__l10n']['Depending on the size of your blog, it could take a few minutes.'] = 'Selon la taille de votre blog, ceci peut prendre quelques minutes.';
$GLOBALS['__l10n']['General information'] = 'Informations générales';
$GLOBALS['__l10n']['Import my blog now'] = 'Importer mon blog';
$GLOBALS['__l10n']['We first need some information about your old Dotclear 1.2 installation.'] = 'Nous avons d\'abord besoin de renseignements à propos de votre ancienne installation Dotclear 1.2.';
$GLOBALS['__l10n']['Entries import options'] = 'Options d\'importation des billets';
$GLOBALS['__l10n']['Number of entries to import at once:'] = 'Nombre de billets à importer à chaque étape :';
$GLOBALS['__l10n']['Importing users'] = 'Importe les utilisateurs';
$GLOBALS['__l10n']['Importing categories'] = 'Importe les catégories';
$GLOBALS['__l10n']['Importing blogroll'] = 'Importe les liens';
$GLOBALS['__l10n']['Importing entries from %d to %d / %d'] = 'Importation des billets %d à %d';
$GLOBALS['__l10n']['Please read carefully'] = 'Merci de lire attentivement';
$GLOBALS['__l10n']['next step'] = 'étape suivante';
$GLOBALS['__l10n']['Dotclear tables not found'] = 'Tables Dotclear non trouvées';
$GLOBALS['__l10n']['Feed import'] = 'Importer depuis un flux';
$GLOBALS['__l10n']['Imports a feed as new entries.'] = 'Importe un flux comme nouveaux billets.';
$GLOBALS['__l10n']['Cannot retrieve feed URL.'] = 'Impossible d\'atteindre l\'URL du fil.';
$GLOBALS['__l10n']['No items in feed.'] = 'Aucun élément dans le fil.';
$GLOBALS['__l10n']['Content successfully imported.'] = 'Contenu importé avec succès.';
$GLOBALS['__l10n']['This will import a feed (RSS or Atom) a as new content in the current blog: %s.'] = 'Ceci va importer un fil (RSS ou Atom) comme un nouveau contenu dans le blog en cours : %s.';
$GLOBALS['__l10n']['Feed URL:'] = 'URL du fil :';
$GLOBALS['__l10n']['Import'] = 'Importer';
$GLOBALS['__l10n']['Flat file import'] = 'Importer depuis un fichier texte';
$GLOBALS['__l10n']['Imports a blog or a full Dotclear installation from flat file.'] = 'Importe un blog ou toutes les données depuis un fichier texte.';
$GLOBALS['__l10n']['Single blog successfully imported.'] = 'Blog importé avec succès.';
$GLOBALS['__l10n']['Are you sure you want to import a full backup file?'] = 'Êtes-vous certain de vouloir charger un fichier de sauvegarde complet ?';
$GLOBALS['__l10n']['This will import a single blog backup as new content in the current blog: %s.'] = 'Ceci va charger une sauvegarde de blog comme un nouveau contenu dans le blog en cours : %s.';
$GLOBALS['__l10n']['Upload a backup file'] = 'Charger un fichier de sauvegarde';
$GLOBALS['__l10n']['or pick up a local file in your public directory'] = 'ou choisissez un fichier local dans votre répertoire public';
$GLOBALS['__l10n']['This will reset all the content of your database, except users.'] = 'Ceci va remettre à zéro tout le contenu, sauf les utilisateurs.';
$GLOBALS['__l10n']['File is empty or not a compressed file.'] = 'Le Fichier est vide ou n\'est pas un fichier compressé.';
$GLOBALS['__l10n']['Another file with same name exists.'] = 'Un autre fichier du même nom existe déjà.';
$GLOBALS['__l10n']['Failed to extract backup file.'] = 'Impossible d\'extraire le fichier de sauvegarde.';
$GLOBALS['__l10n']['No backup in compressed file.'] = 'Pas de sauvegarde dans le fichier compressé.';
$GLOBALS['__l10n']['WordPress import'] = 'Importer depuis WordPress';
$GLOBALS['__l10n']['Import a WordPress installation into your current blog.'] = 'Importe un blog WordPress dans votre blog en cours.';
$GLOBALS['__l10n']['This will import your WordPress content as new content in the current blog: %s.'] = 'Ceci va importer votre blog WordPress comme un nouveau contenu dans le blog en cours : %s.';
$GLOBALS['__l10n']['We first need some information about your old WordPress installation.'] = 'Nous avons d\'abord besoin de renseignements à propos de votre ancienne installation WordPress.';
$GLOBALS['__l10n']['Ignore the first category:'] = 'Ignorer la première catégorie :';
$GLOBALS['__l10n']['Import lowest numbered category on posts:'] = 'Importer la catégorie la plus ancienne sur les articles :';
$GLOBALS['__l10n']['Import all categories as tags:'] = 'Importer les catégories comme des mots-clés :';
$GLOBALS['__l10n']['Prefix such tags with:'] = 'Préfixer ces mots-clés avec :';
$GLOBALS['__l10n']['Content filters'] = 'Filtres de contenu';
$GLOBALS['__l10n']['You may want to process your post and/or comment content with the following filters.'] = 'Vous pouvez utiliser les filtres suivants sur vos articles et/ou commentaires.';
$GLOBALS['__l10n']['Post content formatter:'] = 'Formatage des articles :';
$GLOBALS['__l10n']['Comment content formatter:'] = 'Formatage des commentaires :';
$GLOBALS['__l10n']['WordPress tables not found'] = 'Tables WordPress non trouvées';
$GLOBALS['__l10n']['No file to read.'] = 'Aucun fichier lisible.';
$GLOBALS['__l10n']['File is not a DotClear backup.'] = 'Le fichier n\'est pas une sauvegarde DotClear.';
$GLOBALS['__l10n']['File is not a single blog export.'] = 'Le fichier n\'est pas un fichier d\'export simple.';
$GLOBALS['__l10n']['File is not a full export.'] = 'Le fichier n\'est pas un fichier d\'export complet.';
$GLOBALS['__l10n']['ID of "%3$s" does not match on record "%1$s" at line %2$s of backup file.'] = 'L\'ID de "%3$s" ne correspond pas dans l\'enregistrement de "%1$s" à la ligne %2$s du fichier de sauvegarde.';
$GLOBALS['__l10n']['Please wait...'] = 'Veuillez patienter...';
?>

==> dotclear-2.5.1.zip: dotclear/plugins/importExport/locales/fr/main.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n'][''] = '
Content-Type: text/plain; charset=UTF-8n
Project-Id-Version: importExport 3.1n
POT-Creation-Date: n
PO-Revision-Date: 2012-07-09T14:37:32+00:00n
Last-Translator: Jean-Christian Denisn
Language-Team: n
MIME-Version: 1.0n
Content-Transfer-Encoding: 8bitn';
$GLOBALS['__l10n']['Import/Export'] = 'Import/Export';
$GLOBALS['__l10n']['Flat file export'] = 'Exporter un fichier texte';
$GLOBALS['__l10n']['Exports a blog or a full Dotclear installation to flat file.'] = 'Exporte un blog ou toutes les données de Dotclear dans un fichier texte.';
$GLOBALS['__l10n']['Export file not found.'] = 'Fichier d\'export non trouvé.';
$GLOBALS['__l10n']['Failed to compress export file.'] = 'Impossible de compresser le fichier d\'export.';
$GLOBALS['__l10n']['Single blog'] = 'Un seul blog';
$GLOBALS['__l10n']['This will create an export of your current blog: %s'] = 'Ceci va exporter le contenu du blog en cours : %s.';
$GLOBALS['__l10n']['File name:'] = 'Nom du fichier :';
$GLOBALS['__l10n']['Compress file'] = 'Compresser le fichier';
$GLOBALS['__l10n']['You may also want to download your media directory as a zip file'] = 'Vous pouvez également télécharger votre répertoire de médias au format zip.';
$GLOBALS['__l10n']['Export'] = 'Exporter';
$GLOBALS['__l10n']['Multiple blogs'] = 'Tous les blogs';
$GLOBALS['__l10n']['This will create an export of all the content of your database.'] = 'Ceci va exporter le contenu complet de votre base de données.';
$GLOBALS['__l10n']['Congratulation!'] = 'Félicitations !';
$GLOBALS['__l10n']['Your blog has been successfully imported. Welcome on Dotclear 2!'] = 'Votre blog a été importé avec succès. Bienvenue sur Dotclear 2 !';
$GLOBALS['__l10n']['Why don\'t you blog this now?'] = 'Pourquoi ne pas le bloguer maintenant ?';
$GLOBALS['__l10n']['or'] = 'ou';
$GLOBALS['__l10n']['visit your dashboard'] = 'vous rendre sur votre tableau de bord';
$GLOBALS['__l10n']['Dotclear 1.2 import'] = 'Importer depuis Dotclear 1.2';
$GLOBALS['__l10n']['Import a Dotclear 1.2 installation into your current blog.'] = 'Importe un blog Dotclear 1.2 dans votre blog en cours.';
$GLOBALS['__l10n']['This will import your Dotclear 1.2 content as new content in the current blog: %s.'] = 'Ceci va importer votre blog Dotclear 1.2 comme un nouveau contenu dans le blog en cours : %s.';
$GLOBALS['__l10n']['Depending on the size of your blog, it could take a few minutes.'] = 'Selon la taille de votre blog, ceci peut prendre quelques minutes.';
$GLOBALS['__l10n']['General information'] = 'Informations générales';
$GLOBALS['__l10n']['Import my blog now'] = 'Importer mon blog';
$GLOBALS['__l10n']['We first need some information about your old Dotclear 1.2 installation.'] = 'Nous avons d\'abord besoin de renseignements à propos de votre ancienne installation Dotclear 1.2.';
$GLOBALS['__l10n']['Entries import options'] = 'Options d\'importation des billets';
$GLOBALS['__l10n']['Number of entries to import at once:'] = 'Nombre de billets à importer à chaque étape :';
$GLOBALS['__l10n']['Importing users'] = 'Importe les utilisateurs';
$GLOBALS['__l10n']['Importing categories'] = 'Importe les catégories';
$GLOBALS['__l10n']['Importing blogroll'] = 'Importe les liens';
$GLOBALS['__l10n']['Importing entries from %d to %d / %d'] = 'Importation des billets %d à %d';
$GLOBALS['__l10n']['Please read carefully'] = 'Merci de lire attentivement';
$GLOBALS['__l10n']['next step'] = 'étape suivante';
$GLOBALS['__l10n']['Dotclear tables not found'] = 'Tables Dotclear non trouvées';
$GLOBALS['__l10n']['Feed import'] = 'Importer depuis un flux';
$GLOBALS['__l10n']['Imports a feed as new entries.'] = 'Importe un flux comme nouveaux billets.';
$GLOBALS['__l10n']['Cannot retrieve feed URL.'] = 'Impossible d\'atteindre l\'URL du fil.';
$GLOBALS['__l10n']['No items in feed.'] = 'Aucun élément dans le fil.';
$GLOBALS['__l10n']['Content successfully imported.'] = 'Contenu importé avec succès.';
$GLOBALS['__l10n']['This will import a feed (RSS or Atom) a as new content in the current blog: %s.'] = 'Ceci va importer un fil (RSS ou Atom) comme un nouveau contenu dans le blog en cours : %s.';
$GLOBALS['__l10n']['Feed URL:'] = 'URL du fil :';
$GLOBALS['__l10n']['Import'] = 'Importer';
$GLOBALS['__l10n']['Flat file import'] = 'Importer depuis un fichier texte';
$GLOBALS['__l10n']['Imports a blog or a full Dotclear installation from flat file.'] = 'Importe un blog ou toutes les données depuis un fichier texte.';
$GLOBALS['__l10n']['Single blog successfully imported.'] = 'Blog importé avec succès.';
$GLOBALS['__l10n']['Are you sure you want to import a full backup file?'] = 'Êtes-vous certain de vouloir charger un fichier de sauvegarde complet ?';
$GLOBALS['__l10n']['This will import a single blog backup as new content in the current blog: %s.'] = 'Ceci va charger une sauvegarde de blog comme un nouveau contenu dans le blog en cours : %s.';
$GLOBALS['__l10n']['Upload a backup file'] = 'Charger un fichier de sauvegarde';
$GLOBALS['__l10n']['or pick up a local file in your public directory'] = 'ou choisissez un fichier local dans votre répertoire public';
$GLOBALS['__l10n']['This will reset all the content of your database, except users.'] = 'Ceci va remettre à zéro tout le contenu, sauf les utilisateurs.';
$GLOBALS['__l10n']['File is empty or not a compressed file.'] = 'Le Fichier est vide ou n\'est pas un fichier compressé.';
$GLOBALS['__l10n']['Another file with same name exists.'] = 'Un autre fichier du même nom existe déjà.';
$GLOBALS['__l10n']['Failed to extract backup file.'] = 'Impossible d\'extraire le fichier de sauvegarde.';
$GLOBALS['__l10n']['No backup in compressed file.'] = 'Pas de sauvegarde dans le fichier compressé.';
$GLOBALS['__l10n']['WordPress import'] = 'Importer depuis WordPress';
$GLOBALS['__l10n']['Import a WordPress installation into your current blog.'] = 'Importe un blog WordPress dans votre blog en cours.';
$GLOBALS['__l10n']['This will import your WordPress content as new content in the current blog: %s.'] = 'Ceci va importer votre blog WordPress comme un nouveau contenu dans le blog en cours : %s.';
$GLOBALS['__l10n']['We first need some information about your old WordPress installation.'] = 'Nous avons d\'abord besoin de renseignements à propos de votre ancienne installation WordPress.';
$GLOBALS['__l10n']['Ignore the first category:'] = 'Ignorer la première catégorie :';
$GLOBALS['__l10n']['Import lowest numbered category on posts:'] = 'Importer la catégorie la plus ancienne sur les articles :';
$GLOBALS['__l10n']['Import all categories as tags:'] = 'Importer les catégories comme des mots-clés :';
$GLOBALS['__l10n']['Prefix such tags with:'] = 'Préfixer ces mots-clés avec :';
$GLOBALS['__l10n']['Content filters'] = 'Filtres de contenu';
$GLOBALS['__l10n']['You may want to process your post and/or comment content with the following filters.'] = 'Vous pouvez utiliser les filtres suivants sur vos articles et/ou commentaires.';
$GLOBALS['__l10n']['Post content formatter:'] = 'Formatage des articles :';
$GLOBALS['__l10n']['Comment content formatter:'] = 'Formatage des commentaires :';
$GLOBALS['__l10n']['WordPress tables not found'] = 'Tables WordPress non trouvées';
$GLOBALS['__l10n']['No file to read.'] = 'Aucun fichier lisible.';
$GLOBALS['__l10n']['File is not a DotClear backup.'] = 'Le fichier n\'est pas une sauvegarde DotClear.';
$GLOBALS['__l10n']['File is not a single blog export.'] = 'Le fichier n\'est pas un fichier d\'export simple.';
$GLOBALS['__l10n']['File is not a full export.'] = 'Le fichier n\'est pas un fichier d\'export complet.';
$GLOBALS['__l10n']['ID of "%3$s" does not match on record "%1$s" at line %2$s of backup file.'] = 'L\'ID de "%3$s" ne correspond pas dans l\'enregistrement de "%1$s" à la ligne %2$s du fichier de sauvegarde.';
$GLOBALS['__l10n']['Please wait...'] = 'Veuillez patienter...';
?>
